/*
 * Copyright (c) 2010 Commsen International. All rights reserved.
 * 
 * This file is part of JWebThumb library.
 *	
 * JWebThumb library is free software: you can redistribute it and/or modify 
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 * 
 * JWebThumb library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with JWebThumb library.  If not, see <http://www.gnu.org/licenses/lgpl.html>.
 */

package com.commsen.jwebthumb.simplexml;

import java.text.SimpleDateFormat;
import java.util.Date;

import org.simpleframework.xml.transform.Transform;

/**
 * Implementation of {@link Transform} which transforms dates according to
 * <code>yyyy-MM-dd HH:mm:ss</code> format.
 * 
 * @author <a href="mailto:MilenDyankov@gmail.com">Milen Dyankov</a>
 * @since 0.3
 */
public class DateTransformer implements Transform<Date> {

	public final SimpleDateFormat timeFormat = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");


	/**
	 * @see org.simpleframework.xml.transform.Transform#read(java.lang.String)
	 */
	public Date read(String value) throws Exception {
		return timeFormat.parse(value);
	}


	/**
	 * @see org.simpleframework.xml.transform.Transform#write(java.lang.Object)
	 */
	public String write(Date value) throws Exception {
		return timeFormat.format(value);
	}

}
